==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fFstore.h <==
// class soot.coffi.Instruction_Fstore

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 3b0b49e1ecc8f7a2 soot_coffi_Instruction__5fFstore
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fFstore_H_
#define _JC_soot_coffi_Instruction__5fFstore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fFstore$sub_refs	_jc_soot_coffi_Instruction__5fFstore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fFstore$sub_nonrefs	_jc_soot_coffi_Instruction__5fFstore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFstore$refs	_jc_soot_coffi_Instruction__5fFstore$refs;
typedef struct _jc_soot_coffi_Instruction__5fFstore$nonrefs	_jc_soot_coffi_Instruction__5fFstore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFstore$object	_jc_soot_coffi_Instruction__5fFstore$object;

typedef const struct _jc_soot_coffi_Instruction__5fFstore$vmethods	_jc_soot_coffi_Instruction__5fFstore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fFstore$vtable	_jc_soot_coffi_Instruction__5fFstore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fFstore$vtype	_jc_soot_coffi_Instruction__5fFstore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fFstore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fFstore$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fFstore$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fFstore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fFstore$vmethods	soot_coffi_Instruction__5fFstore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fFstore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fFstore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFstore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFstore$refs {
    _jc_soot_coffi_Instruction__5fFstore$sub_refs	soot_coffi_Instruction__5fFstore;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFstore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFstore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fFstore$sub_nonrefs	soot_coffi_Instruction__5fFstore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fFstore$object {
	_jc_soot_coffi_Instruction__5fFstore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fFstore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fFstore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fFstore$vtype _jc_soot_coffi_Instruction__5fFstore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fFstore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fFstore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fFstore_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fFstore.h <==
// class soot.coffi.Instruction_Fstore

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 3b0b49e1ecc8f7a2 soot_coffi_Instruction__5fFstore
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fFstore_H_
#define _JC_soot_coffi_Instruction__5fFstore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fFstore$sub_refs	_jc_soot_coffi_Instruction__5fFstore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fFstore$sub_nonrefs	_jc_soot_coffi_Instruction__5fFstore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFstore$refs	_jc_soot_coffi_Instruction__5fFstore$refs;
typedef struct _jc_soot_coffi_Instruction__5fFstore$nonrefs	_jc_soot_coffi_Instruction__5fFstore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFstore$object	_jc_soot_coffi_Instruction__5fFstore$object;

typedef const struct _jc_soot_coffi_Instruction__5fFstore$vmethods	_jc_soot_coffi_Instruction__5fFstore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fFstore$vtable	_jc_soot_coffi_Instruction__5fFstore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fFstore$vtype	_jc_soot_coffi_Instruction__5fFstore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fFstore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fFstore$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fFstore$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fFstore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fFstore$vmethods	soot_coffi_Instruction__5fFstore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fFstore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fFstore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFstore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFstore$refs {
    _jc_soot_coffi_Instruction__5fFstore$sub_refs	soot_coffi_Instruction__5fFstore;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFstore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFstore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fFstore$sub_nonrefs	soot_coffi_Instruction__5fFstore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fFstore$object {
	_jc_soot_coffi_Instruction__5fFstore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fFstore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fFstore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fFstore$vtype _jc_soot_coffi_Instruction__5fFstore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fFstore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fFstore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fFstore_H_ */
